pub struct CostInfo {
pub currency: String,
pub estimated_api_equivalent_usd: Option<i64>,
pub provider_reported_usd: Option<i64>,
pub pricing_source: Option<String>,
pub pricing_version: Option<String>,
pub confidence: Confidence,
}Fields
currency: Stringestimated_api_equivalent_usd: Option<i64>provider_reported_usd: Option<i64>pricing_source: Option<String>pricing_version: Option<String>confidence: ConfidenceTrait Implementations
Sourceimpl<'de> Deserialize<'de> for CostInfo
impl<'de> Deserialize<'de> for CostInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CostInfo
impl JsonSchema for CostInfo
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for CostInfo