pub struct DailyRollup {Show 15 fields
pub schema_version: String,
pub date: String,
pub device_id: String,
pub total_input_tokens: u64,
pub total_cache_creation_tokens: u64,
pub total_cache_read_tokens: u64,
pub total_output_tokens: u64,
pub total_reasoning_tokens: u64,
pub total_tokens: u64,
pub total_events: u64,
pub total_sessions: u64,
pub estimated_cost_usd: Option<i64>,
pub by_provider: Option<String>,
pub by_account: Option<String>,
pub updated_at: DateTime<Utc>,
}Fields
schema_version: Stringdate: Stringdevice_id: Stringtotal_input_tokens: u64total_cache_creation_tokens: u64total_cache_read_tokens: u64total_output_tokens: u64total_reasoning_tokens: u64total_tokens: u64total_events: u64total_sessions: u64estimated_cost_usd: Option<i64>by_provider: Option<String>by_account: Option<String>updated_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for DailyRollup
impl Clone for DailyRollup
Sourcefn clone(&self) -> DailyRollup
fn clone(&self) -> DailyRollup
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DailyRollup
impl Debug for DailyRollup
Sourceimpl<'de> Deserialize<'de> for DailyRollup
impl<'de> Deserialize<'de> for DailyRollup
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DailyRollup
impl JsonSchema for DailyRollup
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DailyRollup
impl PartialEq for DailyRollup
Sourcefn eq(&self, other: &DailyRollup) -> bool
fn eq(&self, other: &DailyRollup) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DailyRollup
impl Serialize for DailyRollup
impl StructuralPartialEq for DailyRollup