pub struct GitInfo {
pub nearby_commit_hashes: Vec<String>,
pub nearby_commit_messages: Vec<String>,
pub correlation_confidence: Option<Confidence>,
}Fields
nearby_commit_hashes: Vec<String>nearby_commit_messages: Vec<String>correlation_confidence: Option<Confidence>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for GitInfo
impl<'de> Deserialize<'de> for GitInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for GitInfo
Sourceimpl JsonSchema for GitInfo
impl JsonSchema for GitInfo
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for GitInfo