pub struct MetricStats {
pub samples: u64,
pub avg: Option<f64>,
pub min: Option<f64>,
pub max: Option<f64>,
pub p50: Option<f64>,
pub p95: Option<f64>,
pub sum: Option<f64>,
}Fields
samples: u64avg: Option<f64>min: Option<f64>max: Option<f64>p50: Option<f64>p95: Option<f64>sum: Option<f64>Trait Implementations
Sourceimpl Clone for MetricStats
impl Clone for MetricStats
Sourcefn clone(&self) -> MetricStats
fn clone(&self) -> MetricStats
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MetricStats
impl Debug for MetricStats
Sourceimpl<'de> Deserialize<'de> for MetricStats
impl<'de> Deserialize<'de> for MetricStats
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MetricStats
impl JsonSchema for MetricStats
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MetricStats
impl PartialEq for MetricStats
Sourcefn eq(&self, other: &MetricStats) -> bool
fn eq(&self, other: &MetricStats) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for MetricStats
impl Serialize for MetricStats
impl StructuralPartialEq for MetricStats