pub struct ParseEvidence {
pub event_key_version: String,
pub source_file_path_hash: Option<String>,
pub source_line_number: Option<u64>,
pub source_record_id: Option<String>,
pub model_inferred: bool,
pub timestamp_inferred: bool,
pub account_identity_source: IdentitySource,
}Fields
event_key_version: Stringsource_file_path_hash: Option<String>source_line_number: Option<u64>source_record_id: Option<String>model_inferred: booltimestamp_inferred: boolaccount_identity_source: IdentitySourceTrait Implementations
Sourceimpl Clone for ParseEvidence
impl Clone for ParseEvidence
Sourcefn clone(&self) -> ParseEvidence
fn clone(&self) -> ParseEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ParseEvidence
impl Debug for ParseEvidence
Sourceimpl<'de> Deserialize<'de> for ParseEvidence
impl<'de> Deserialize<'de> for ParseEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ParseEvidence
Sourceimpl JsonSchema for ParseEvidence
impl JsonSchema for ParseEvidence
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ParseEvidence
impl PartialEq for ParseEvidence
Sourcefn eq(&self, other: &ParseEvidence) -> bool
fn eq(&self, other: &ParseEvidence) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ParseEvidence
impl Serialize for ParseEvidence
impl StructuralPartialEq for ParseEvidence