pub struct PrivacyInfo {
pub mode: PrivacyMode,
pub contains_prompt_text: bool,
pub contains_response_text: bool,
pub contains_file_paths: bool,
}Fields
mode: PrivacyModecontains_prompt_text: boolcontains_response_text: boolcontains_file_paths: boolTrait Implementations
Sourceimpl Clone for PrivacyInfo
impl Clone for PrivacyInfo
Sourcefn clone(&self) -> PrivacyInfo
fn clone(&self) -> PrivacyInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PrivacyInfo
impl Debug for PrivacyInfo
Sourceimpl<'de> Deserialize<'de> for PrivacyInfo
impl<'de> Deserialize<'de> for PrivacyInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PrivacyInfo
Sourceimpl JsonSchema for PrivacyInfo
impl JsonSchema for PrivacyInfo
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PrivacyInfo
impl PartialEq for PrivacyInfo
Sourcefn eq(&self, other: &PrivacyInfo) -> bool
fn eq(&self, other: &PrivacyInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PrivacyInfo
impl Serialize for PrivacyInfo
impl StructuralPartialEq for PrivacyInfo