pub struct ProjectInfo {
pub project_id: String,
pub project_label: Option<String>,
pub repo_remote_hash: Option<String>,
pub repo_label: Option<String>,
pub branch_hash: Option<String>,
pub branch_label: Option<String>,
pub path_hash: Option<String>,
pub path_label: Option<String>,
}Fields
project_id: Stringproject_label: Option<String>repo_remote_hash: Option<String>repo_label: Option<String>branch_hash: Option<String>branch_label: Option<String>path_hash: Option<String>path_label: Option<String>Trait Implementations
Sourceimpl Clone for ProjectInfo
impl Clone for ProjectInfo
Sourcefn clone(&self) -> ProjectInfo
fn clone(&self) -> ProjectInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProjectInfo
impl Debug for ProjectInfo
Sourceimpl<'de> Deserialize<'de> for ProjectInfo
impl<'de> Deserialize<'de> for ProjectInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ProjectInfo
Sourceimpl JsonSchema for ProjectInfo
impl JsonSchema for ProjectInfo
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProjectInfo
impl PartialEq for ProjectInfo
Sourcefn eq(&self, other: &ProjectInfo) -> bool
fn eq(&self, other: &ProjectInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProjectInfo
impl Serialize for ProjectInfo
impl StructuralPartialEq for ProjectInfo