pub struct ProviderAccount {Show 15 fields
pub schema_version: String,
pub provider_account_id: ProviderAccountId,
pub provider: String,
pub identity_source: IdentitySource,
pub provider_user_id: Option<String>,
pub email: Option<String>,
pub provider_user_id_hash: Option<String>,
pub email_hash: Option<String>,
pub org_id_hash: Option<String>,
pub account_label: Option<String>,
pub plan_name: Option<String>,
pub confidence: Confidence,
pub verified_at: Option<DateTime<Utc>>,
pub created_at: DateTime<Utc>,
pub updated_at: DateTime<Utc>,
}Fields
schema_version: Stringprovider_account_id: ProviderAccountIdprovider: Stringidentity_source: IdentitySourceprovider_user_id: Option<String>email: Option<String>provider_user_id_hash: Option<String>email_hash: Option<String>org_id_hash: Option<String>account_label: Option<String>plan_name: Option<String>confidence: Confidenceverified_at: Option<DateTime<Utc>>created_at: DateTime<Utc>updated_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for ProviderAccount
impl Clone for ProviderAccount
Sourcefn clone(&self) -> ProviderAccount
fn clone(&self) -> ProviderAccount
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProviderAccount
impl Debug for ProviderAccount
Sourceimpl<'de> Deserialize<'de> for ProviderAccount
impl<'de> Deserialize<'de> for ProviderAccount
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ProviderAccount
Sourceimpl JsonSchema for ProviderAccount
impl JsonSchema for ProviderAccount
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProviderAccount
impl PartialEq for ProviderAccount
Sourcefn eq(&self, other: &ProviderAccount) -> bool
fn eq(&self, other: &ProviderAccount) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProviderAccount
impl Serialize for ProviderAccount
impl StructuralPartialEq for ProviderAccount