pub struct ProviderAccountId(pub String);Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for ProviderAccountId
impl Clone for ProviderAccountId
Sourcefn clone(&self) -> ProviderAccountId
fn clone(&self) -> ProviderAccountId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProviderAccountId
impl Debug for ProviderAccountId
Sourceimpl<'de> Deserialize<'de> for ProviderAccountId
impl<'de> Deserialize<'de> for ProviderAccountId
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ProviderAccountId
Sourceimpl Hash for ProviderAccountId
impl Hash for ProviderAccountId
Sourceimpl JsonSchema for ProviderAccountId
impl JsonSchema for ProviderAccountId
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourceimpl PartialEq for ProviderAccountId
impl PartialEq for ProviderAccountId
Sourcefn eq(&self, other: &ProviderAccountId) -> bool
fn eq(&self, other: &ProviderAccountId) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProviderAccountId
impl Serialize for ProviderAccountId
impl StructuralPartialEq for ProviderAccountId