pub struct RuntimeInfo {
pub runtime_name: Option<String>,
pub host_id: Option<String>,
pub latency_ms: Option<u64>,
pub latency_source: Option<LatencySource>,
pub time_to_first_token_ms: Option<u64>,
pub prompt_eval_duration_ms: Option<u64>,
pub eval_duration_ms: Option<u64>,
pub total_messages: Option<u64>,
pub user_messages: Option<u64>,
pub assistant_messages: Option<u64>,
pub developer_messages: Option<u64>,
}Fields
runtime_name: Option<String>host_id: Option<String>latency_ms: Option<u64>End-to-end request or turn duration, not time to first token.
latency_source: Option<LatencySource>Provenance of latency_ms when the adapter can distinguish it.
time_to_first_token_ms: Option<u64>Time from request start until the first visible token arrives.
prompt_eval_duration_ms: Option<u64>eval_duration_ms: Option<u64>total_messages: Option<u64>user_messages: Option<u64>assistant_messages: Option<u64>developer_messages: Option<u64>Trait Implementations
Sourceimpl Clone for RuntimeInfo
impl Clone for RuntimeInfo
Sourcefn clone(&self) -> RuntimeInfo
fn clone(&self) -> RuntimeInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RuntimeInfo
impl Debug for RuntimeInfo
Sourceimpl<'de> Deserialize<'de> for RuntimeInfo
impl<'de> Deserialize<'de> for RuntimeInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RuntimeInfo
Sourceimpl JsonSchema for RuntimeInfo
impl JsonSchema for RuntimeInfo
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RuntimeInfo
impl PartialEq for RuntimeInfo
Sourcefn eq(&self, other: &RuntimeInfo) -> bool
fn eq(&self, other: &RuntimeInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RuntimeInfo
impl Serialize for RuntimeInfo
impl StructuralPartialEq for RuntimeInfo