pub struct SourceAccountAssignment {
pub schema_version: String,
pub assignment_id: SourceAccountAssignmentId,
pub source_id: SourceId,
pub provider: String,
pub provider_account_id: ProviderAccountId,
pub started_at: DateTime<Utc>,
pub ended_at: Option<DateTime<Utc>>,
pub record_source: IdentitySource,
pub verified_at: Option<DateTime<Utc>>,
pub created_at: DateTime<Utc>,
pub updated_at: DateTime<Utc>,
}Fields
schema_version: Stringassignment_id: SourceAccountAssignmentIdsource_id: SourceIdprovider: Stringprovider_account_id: ProviderAccountIdstarted_at: DateTime<Utc>ended_at: Option<DateTime<Utc>>record_source: IdentitySourceverified_at: Option<DateTime<Utc>>created_at: DateTime<Utc>updated_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for SourceAccountAssignment
impl Clone for SourceAccountAssignment
Sourcefn clone(&self) -> SourceAccountAssignment
fn clone(&self) -> SourceAccountAssignment
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SourceAccountAssignment
impl Debug for SourceAccountAssignment
Sourceimpl<'de> Deserialize<'de> for SourceAccountAssignment
impl<'de> Deserialize<'de> for SourceAccountAssignment
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SourceAccountAssignment
Sourceimpl JsonSchema for SourceAccountAssignment
impl JsonSchema for SourceAccountAssignment
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SourceAccountAssignment
impl PartialEq for SourceAccountAssignment
Sourcefn eq(&self, other: &SourceAccountAssignment) -> bool
fn eq(&self, other: &SourceAccountAssignment) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SourceAccountAssignment
impl Serialize for SourceAccountAssignment
impl StructuralPartialEq for SourceAccountAssignment