pub struct Subscription {Show 17 fields
pub schema_version: String,
pub subscription_id: SubscriptionId,
pub provider: String,
pub provider_account_id: ProviderAccountId,
pub plan_name: String,
pub price: i64,
pub currency: String,
pub billing_period: BillingPeriod,
pub paid_at: Option<DateTime<Utc>>,
pub renewal_day: Option<u8>,
pub started_at: DateTime<Utc>,
pub ended_at: Option<DateTime<Utc>>,
pub current_period_ends_at: Option<DateTime<Utc>>,
pub status: SubscriptionStatus,
pub record_source: IdentitySource,
pub verified_at: Option<DateTime<Utc>>,
pub notes: Option<String>,
}Fields
schema_version: Stringsubscription_id: SubscriptionIdprovider: Stringprovider_account_id: ProviderAccountIdplan_name: Stringprice: i64currency: Stringbilling_period: BillingPeriodpaid_at: Option<DateTime<Utc>>renewal_day: Option<u8>started_at: DateTime<Utc>ended_at: Option<DateTime<Utc>>current_period_ends_at: Option<DateTime<Utc>>status: SubscriptionStatusrecord_source: IdentitySourceverified_at: Option<DateTime<Utc>>notes: Option<String>Trait Implementations
Sourceimpl Clone for Subscription
impl Clone for Subscription
Sourcefn clone(&self) -> Subscription
fn clone(&self) -> Subscription
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Subscription
impl Debug for Subscription
Sourceimpl<'de> Deserialize<'de> for Subscription
impl<'de> Deserialize<'de> for Subscription
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Subscription
impl JsonSchema for Subscription
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for Subscription
impl PartialEq for Subscription
Sourcefn eq(&self, other: &Subscription) -> bool
fn eq(&self, other: &Subscription) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for Subscription
impl Serialize for Subscription
impl StructuralPartialEq for Subscription