pub struct SubscriptionId(pub String);Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for SubscriptionId
impl Clone for SubscriptionId
Sourcefn clone(&self) -> SubscriptionId
fn clone(&self) -> SubscriptionId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SubscriptionId
impl Debug for SubscriptionId
Sourceimpl<'de> Deserialize<'de> for SubscriptionId
impl<'de> Deserialize<'de> for SubscriptionId
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SubscriptionId
Sourceimpl Hash for SubscriptionId
impl Hash for SubscriptionId
Sourceimpl JsonSchema for SubscriptionId
impl JsonSchema for SubscriptionId
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourceimpl PartialEq for SubscriptionId
impl PartialEq for SubscriptionId
Sourcefn eq(&self, other: &SubscriptionId) -> bool
fn eq(&self, other: &SubscriptionId) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SubscriptionId
impl Serialize for SubscriptionId
impl StructuralPartialEq for SubscriptionId