pub struct SummaryMetadata {
pub summary_format: String,
pub summary_version: Option<String>,
pub total_sessions: Option<u64>,
pub total_messages: Option<u64>,
pub last_computed_at: Option<DateTime<Utc>>,
}Fields
summary_format: Stringsummary_version: Option<String>total_sessions: Option<u64>total_messages: Option<u64>last_computed_at: Option<DateTime<Utc>>Trait Implementations
Sourceimpl Clone for SummaryMetadata
impl Clone for SummaryMetadata
Sourcefn clone(&self) -> SummaryMetadata
fn clone(&self) -> SummaryMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SummaryMetadata
impl Debug for SummaryMetadata
Sourceimpl<'de> Deserialize<'de> for SummaryMetadata
impl<'de> Deserialize<'de> for SummaryMetadata
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SummaryMetadata
Sourceimpl JsonSchema for SummaryMetadata
impl JsonSchema for SummaryMetadata
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SummaryMetadata
impl PartialEq for SummaryMetadata
Sourcefn eq(&self, other: &SummaryMetadata) -> bool
fn eq(&self, other: &SummaryMetadata) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SummaryMetadata
impl Serialize for SummaryMetadata
impl StructuralPartialEq for SummaryMetadata