pub struct SummaryMetrics {Show 16 fields
pub active_seconds: Option<f64>,
pub tracked_requests: Option<u64>,
pub tracked_output_tokens: Option<u64>,
pub tracked_reasoning_tokens: Option<u64>,
pub latency_ms: Option<MetricStats>,
pub time_to_first_token_ms: Option<MetricStats>,
pub generated_tps: Option<MetricStats>,
pub visible_tps: Option<MetricStats>,
pub overall_generated_tps: Option<f64>,
pub overall_visible_tps: Option<f64>,
pub cache_hit_ratio: Option<MetricStats>,
pub reasoning_share: Option<MetricStats>,
pub total_messages: Option<u64>,
pub user_messages: Option<u64>,
pub assistant_messages: Option<u64>,
pub developer_messages: Option<u64>,
}Fields
active_seconds: Option<f64>tracked_requests: Option<u64>tracked_output_tokens: Option<u64>tracked_reasoning_tokens: Option<u64>latency_ms: Option<MetricStats>Aggregated end-to-end request or turn duration, not TTFT.
time_to_first_token_ms: Option<MetricStats>generated_tps: Option<MetricStats>Per-turn generated throughput distribution across tracked turns.
visible_tps: Option<MetricStats>Per-turn visible throughput distribution across tracked turns.
overall_generated_tps: Option<f64>Overall generated throughput across tracked active time.
overall_visible_tps: Option<f64>Overall visible throughput across tracked active time.
cache_hit_ratio: Option<MetricStats>total_messages: Option<u64>user_messages: Option<u64>assistant_messages: Option<u64>developer_messages: Option<u64>Trait Implementations
Sourceimpl Clone for SummaryMetrics
impl Clone for SummaryMetrics
Sourcefn clone(&self) -> SummaryMetrics
fn clone(&self) -> SummaryMetrics
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SummaryMetrics
impl Debug for SummaryMetrics
Sourceimpl<'de> Deserialize<'de> for SummaryMetrics
impl<'de> Deserialize<'de> for SummaryMetrics
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SummaryMetrics
impl JsonSchema for SummaryMetrics
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SummaryMetrics
impl PartialEq for SummaryMetrics
Sourcefn eq(&self, other: &SummaryMetrics) -> bool
fn eq(&self, other: &SummaryMetrics) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SummaryMetrics
impl Serialize for SummaryMetrics
impl StructuralPartialEq for SummaryMetrics