pub struct SummaryModelUsage {
pub model: ModelInfo,
pub usage: UsageCounts,
pub cost: CostInfo,
}Fields
model: ModelInfousage: UsageCountscost: CostInfoTrait Implementations
Sourceimpl Clone for SummaryModelUsage
impl Clone for SummaryModelUsage
Sourcefn clone(&self) -> SummaryModelUsage
fn clone(&self) -> SummaryModelUsage
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SummaryModelUsage
impl Debug for SummaryModelUsage
Sourceimpl<'de> Deserialize<'de> for SummaryModelUsage
impl<'de> Deserialize<'de> for SummaryModelUsage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SummaryModelUsage
impl JsonSchema for SummaryModelUsage
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SummaryModelUsage
impl PartialEq for SummaryModelUsage
Sourcefn eq(&self, other: &SummaryModelUsage) -> bool
fn eq(&self, other: &SummaryModelUsage) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SummaryModelUsage
impl Serialize for SummaryModelUsage
impl StructuralPartialEq for SummaryModelUsage