pub struct SyncAck {
pub schema_version: String,
pub batch_id: String,
pub accepted: SyncEntityCounts,
pub duplicates: SyncEntityCounts,
pub rejected: Vec<SyncRejectedRecord>,
}Fields
schema_version: Stringbatch_id: Stringaccepted: SyncEntityCountsduplicates: SyncEntityCountsrejected: Vec<SyncRejectedRecord>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for SyncAck
impl<'de> Deserialize<'de> for SyncAck
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SyncAck
Sourceimpl JsonSchema for SyncAck
impl JsonSchema for SyncAck
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for SyncAck