pub struct SyncBatch {
pub schema_version: String,
pub batch_id: String,
pub device_id: String,
pub sources: Vec<SourceLocation>,
pub accounts: Vec<ProviderAccount>,
pub source_account_assignments: Vec<SourceAccountAssignment>,
pub subscriptions: Vec<Subscription>,
pub events: Vec<UsageEvent>,
pub summaries: Vec<UsageSummary>,
pub created_at: DateTime<Utc>,
}Fields
schema_version: Stringbatch_id: Stringdevice_id: Stringsources: Vec<SourceLocation>accounts: Vec<ProviderAccount>source_account_assignments: Vec<SourceAccountAssignment>subscriptions: Vec<Subscription>events: Vec<UsageEvent>summaries: Vec<UsageSummary>created_at: DateTime<Utc>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for SyncBatch
impl<'de> Deserialize<'de> for SyncBatch
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SyncBatch
impl JsonSchema for SyncBatch
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for SyncBatch