pub struct SyncEntityCounts {
pub sources: u64,
pub accounts: u64,
pub source_account_assignments: u64,
pub subscriptions: u64,
pub events: u64,
pub summaries: u64,
}Fields
sources: u64accounts: u64source_account_assignments: u64subscriptions: u64events: u64summaries: u64Trait Implementations
Sourceimpl Clone for SyncEntityCounts
impl Clone for SyncEntityCounts
Sourcefn clone(&self) -> SyncEntityCounts
fn clone(&self) -> SyncEntityCounts
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SyncEntityCounts
impl Debug for SyncEntityCounts
Sourceimpl<'de> Deserialize<'de> for SyncEntityCounts
impl<'de> Deserialize<'de> for SyncEntityCounts
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SyncEntityCounts
Sourceimpl JsonSchema for SyncEntityCounts
impl JsonSchema for SyncEntityCounts
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SyncEntityCounts
impl PartialEq for SyncEntityCounts
Sourcefn eq(&self, other: &SyncEntityCounts) -> bool
fn eq(&self, other: &SyncEntityCounts) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SyncEntityCounts
impl Serialize for SyncEntityCounts
impl StructuralPartialEq for SyncEntityCounts