pub struct UsageEvent {Show 19 fields
pub schema_version: String,
pub event_id: EventId,
pub device_id: String,
pub provider: String,
pub source_id: SourceId,
pub provider_account_id: Option<ProviderAccountId>,
pub subscription_id: Option<SubscriptionId>,
pub source: EventSource,
pub session: SessionInfo,
pub model: Option<ModelInfo>,
pub usage: UsageCounts,
pub runtime: Option<RuntimeInfo>,
pub cost: CostInfo,
pub parse_evidence: Option<ParseEvidence>,
pub project: Option<ProjectInfo>,
pub git: Option<GitInfo>,
pub privacy: PrivacyInfo,
pub created_at: DateTime<Utc>,
pub imported_at: DateTime<Utc>,
}Fields
schema_version: Stringevent_id: EventIddevice_id: Stringprovider: Stringsource_id: SourceIdprovider_account_id: Option<ProviderAccountId>subscription_id: Option<SubscriptionId>source: EventSourcesession: SessionInfomodel: Option<ModelInfo>usage: UsageCountsruntime: Option<RuntimeInfo>cost: CostInfoparse_evidence: Option<ParseEvidence>project: Option<ProjectInfo>git: Option<GitInfo>privacy: PrivacyInfocreated_at: DateTime<Utc>imported_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for UsageEvent
impl Clone for UsageEvent
Sourcefn clone(&self) -> UsageEvent
fn clone(&self) -> UsageEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UsageEvent
impl Debug for UsageEvent
Sourceimpl<'de> Deserialize<'de> for UsageEvent
impl<'de> Deserialize<'de> for UsageEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UsageEvent
impl JsonSchema for UsageEvent
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for UsageEvent
impl PartialEq for UsageEvent
Sourcefn eq(&self, other: &UsageEvent) -> bool
fn eq(&self, other: &UsageEvent) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for UsageEvent
impl Serialize for UsageEvent
impl StructuralPartialEq for UsageEvent