pub struct UsageSummary {Show 20 fields
pub schema_version: String,
pub summary_id: SummaryId,
pub device_id: String,
pub provider: String,
pub source_id: SourceId,
pub provider_account_id: Option<ProviderAccountId>,
pub source: EventSource,
pub model: Option<ModelInfo>,
pub models: Vec<SummaryModelUsage>,
pub usage: UsageCounts,
pub cost: CostInfo,
pub parse_evidence: Option<ParseEvidence>,
pub project: Option<ProjectInfo>,
pub privacy: PrivacyInfo,
pub metrics: Option<SummaryMetrics>,
pub period_start: Option<DateTime<Utc>>,
pub period_end: Option<DateTime<Utc>>,
pub observed_at: DateTime<Utc>,
pub metadata: SummaryMetadata,
pub imported_at: DateTime<Utc>,
}Fields
schema_version: Stringsummary_id: SummaryIddevice_id: Stringprovider: Stringsource_id: SourceIdprovider_account_id: Option<ProviderAccountId>source: EventSourcemodel: Option<ModelInfo>models: Vec<SummaryModelUsage>usage: UsageCountscost: CostInfoparse_evidence: Option<ParseEvidence>project: Option<ProjectInfo>privacy: PrivacyInfometrics: Option<SummaryMetrics>period_start: Option<DateTime<Utc>>period_end: Option<DateTime<Utc>>observed_at: DateTime<Utc>metadata: SummaryMetadataimported_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for UsageSummary
impl Clone for UsageSummary
Sourcefn clone(&self) -> UsageSummary
fn clone(&self) -> UsageSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UsageSummary
impl Debug for UsageSummary
Sourceimpl<'de> Deserialize<'de> for UsageSummary
impl<'de> Deserialize<'de> for UsageSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UsageSummary
impl JsonSchema for UsageSummary
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for UsageSummary
impl PartialEq for UsageSummary
Sourcefn eq(&self, other: &UsageSummary) -> bool
fn eq(&self, other: &UsageSummary) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for UsageSummary
impl Serialize for UsageSummary
impl StructuralPartialEq for UsageSummary